@@ -295,21 +295,21 @@ def five_column_100_row_dataset():
     return to_dc_format(df)
 
 
-@pytest.fixture(scope="session", params=[1, 10, 100, 1000])
+@pytest.fixture(params=[1, 10, 100, 1000])
 def batch():
-    size = 100
+    size = 10000
     df = pd.DataFrame(columns=['First', 'Last', 'Gender', 'Birthdate'])
     df['First'] = random_names('first_names', size)
     df['Last'] = random_names('last_names', size)
     df['Gender'] = random_genders(size)
     df['BirthDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
     df['StartDate'] = random_dates(start=pd.to_datetime('1940-01-01'), end=pd.to_datetime('2022-01-01'), size=size)
-    print(sys.getsizeof(to_dc_format(df)))
     return to_dc_format(df)
 
 
-@pytest.fixture(scope="session", params=('size', [1, 10, 100, 1000]))
-def load_data(connector, batch, good_object_id, mapping_object, _replace, size, batch_size):
+@pytest.fixture(scope="session", params=[1, 10, 100, 1000])
+def load_data(connector, batch, good_object_id, mapping_object, _replace, request, batch_size):
+    size = request.param
     total_batches = (size * GB) / batch_size
     batch_number = 1
     rows_loaded = 0
